import 'package:cpt_community/modules/garage/garagesale_detail/garagesale_detail_vm.dart';
import 'package:cpt_community/router/page/community_page_router.dart';
import 'package:cs_resources/theme/app_colors_theme.dart';
import 'package:flutter/material.dart';
import 'package:auto_route/auto_route.dart';
import 'package:flutter_hooks/flutter_hooks.dart';
import 'package:hooks_riverpod/hooks_riverpod.dart';
import 'package:router/ext/auto_router_extensions.dart';
import 'package:shared/utils/color_utils.dart';
import 'package:widgets/load_state_layout.dart';
import 'package:widgets/my_appbar.dart';
import 'package:widgets/my_text_view.dart';

@RoutePage()
class GaragesaleDetailPage extends HookConsumerWidget {
  final int? id;
  final String? type;  // forsale  forrent

  const GaragesaleDetailPage({Key? key, required this.id, required this.type}) : super(key: key);
  // 启动当前页面
  static void startInstance({BuildContext? context, int? id, String? type = 'forsale'}) {
    if (context != null) {
      context.router.push(GaragesaleDetailPageRoute(id: id, type: type));
    } else {
      appRouter.push(GaragesaleDetailPageRoute(id: id, type: type));
    }
  }


  @override
  Widget build(BuildContext context, WidgetRef ref) {
    final state = ref.watch(garagesaleDetailVmProvider);
    final vm = ref.read(garagesaleDetailVmProvider.notifier);

    useEffect((){
      // 组件挂载时执行 - 执行接口请求
      Future.microtask(() => vm.initPageData());
      return () {
        // 组件卸载时执行
      };
    },[]);

    return Scaffold(
      appBar: MyAppBar.appBar(
        context,
        "Garage Sale Detail",
        backgroundColor: context.appColors.whiteBG,
      ),
      backgroundColor: context.appColors.backgroundDefault,
      body: Column(
        children: [
          Expanded(
            child: LoadStateLayout(
              state: state.loadingState,
              errorMessage: state.errorMessage,
              errorRetry: () {
                vm.retryRequest();
              },
              successWidget: SingleChildScrollView(
                scrollDirection: Axis.vertical,
                physics: const BouncingScrollPhysics(),
                clipBehavior: Clip.none,
                child: _buildContentBox(context, ref),
              ),
            ),
          ),
          // 底部联系信息
          Visibility(
            visible: state.loadingState == LoadState.State_Success,
            child: _buildBottomConcatInfo(context, ref),
          )
        ],
      ),
    );
  }


  Widget _buildContentBox(BuildContext context, WidgetRef ref) {
    final vm = ref.read(garagesaleDetailVmProvider.notifier);
    return Column(
      children: [
        Container(
          color: context.appColors.whiteBG,
          child: Column(
            children: [
              Container(
                color: context.appColors.whiteBG,
                child: Column(
                  children: [
                    Container(
                      color: context.appColors.whiteBG,
                      child: Column(
                        children: [
                          Container(
                            color: context.appColors.whiteBG,
                          )
                        ]
                      )
                    )
                  ]
                )
              )
            ]
          )
        )
      ]
    );
  }

  Widget _buildBottomConcatInfo(BuildContext context, WidgetRef ref) {
    return Container(
      height: 50,
      color: ColorUtils.string2Color('#4161D0'),
      child: Row(
        mainAxisAlignment: MainAxisAlignment.center,
        children: [
          // MyLoadImage(Assets.propertyIoanItemBg,width: 60,height: 50,),
          const SizedBox(width: 10,),
          MyTextView(
            "Request a Quote",
            fontSize: 16,
            textColor: Colors.white,
            isFontMedium: true,
          ),
        ],
      ),
    );
  }
}
