import 'package:cpt_profile/modules/profile_edit/dialog/avatar_edit_dialog.dart';
import 'package:flutter/material.dart';
import 'package:plugin_platform/engine/dialog/dialog_engine.dart';
import 'package:plugin_platform/engine/toast/toast_engine.dart';
import 'package:riverpod_annotation/riverpod_annotation.dart';
import 'package:router/ext/auto_router_extensions.dart';
import 'package:shared/utils/log_utils.dart';
import 'profile_edit_state.dart';
import 'package:plugin_platform/platform_export.dart';

part 'profile_edit_view_model.g.dart';

@riverpod
class ProfileEditViewModel extends _$ProfileEditViewModel {
  @override
  ProfileEditState build() {
    return ProfileEditState();
  }

  /// 提交编辑用户信息
  void submitEdit() {
    final FocusNode firstNameFocusNode = state.formData['first_name']!['focusNode'];
    final FocusNode lastNameFocusNode = state.formData['last_name']!['focusNode'];
    final FocusNode emailFocusNode = state.formData['email']!['focusNode'];

    firstNameFocusNode.unfocus();
    lastNameFocusNode.unfocus();
    emailFocusNode.unfocus();

    final TextEditingController firstNameController = state.formData['first_name']!['controller'];
    final TextEditingController lastNameController = state.formData['last_name']!['controller'];
    final TextEditingController emailController = state.formData['email']!['controller'];

    final firstName = firstNameController.text;
    final lastName = lastNameController.text;
    final email = emailController.text;

    Log.d('当前待提交的 firstName:$firstName lastName:$lastName email:$email');

    //执行密码登录
    ToastEngine.show('准备执行请求发送验证码 firstName:$firstName lastName:$lastName email:$email ');

    appRouter.maybePop();
  }

  //去编辑头像页面
  void showAvatarEditDialog(BuildContext context) {
    DialogEngine.show(
        widget: AvatarEditDialog(
      otherAction: (path) {
        ToastEngine.show("点击了图片：$path");
      },
      photoAction: () {
        //选择相机相册
        _pickPhoto(context);
      },
    ));
  }

  //相机相册选择
  void _pickPhoto(BuildContext context) {
    ImagePickerUtils().show(context, (path) {
      ToastEngine.show("选中了图片：$path");
    });
  }
}
